local mod = ...

--[[

    Adds fish ponds to raise fish for food

]]


-- Assets -------------------------------------------------------------------------------------
mod:registerAssetId("models/Pond1.fbx/Prefab/PondPart", "PREFAB_POND1")
mod:registerAssetId("models/Pond2.fbx/Prefab/PondPart", "PREFAB_POND2")
mod:registerAssetId("models/Pond3.fbx/Prefab/PondPart", "PREFAB_POND3")
mod:registerAssetId("models/Pond3.fbx/Prefab/PondPart/Log.001", "PREFAB_POST")



-- Building Asset Processor
mod:registerAssetProcessor("models/Pond1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/Pond2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/Pond3.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Collider Platform (climbable mesh)  -------------------------------------------------------------------------------------
mod:configurePrefabFlagList("models/Pond1.fbx/Prefab/PondPart", { "PLATFORM" })
mod:configurePrefabFlagList("models/Pond2.fbx/Prefab/PondPart", { "PLATFORM" })
mod:configurePrefabFlagList("models/Pond3.fbx/Prefab/PondPart", { "PLATFORM" })



-- Building: Fish Pond -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING",
	Id = "FISHPOND",
	Name = "FISHPOND_NAME",
	Description = "FISHPOND_DESC",
    BuildingType = "GENERAL",
	AssetCoreBuildingPart = "POND_POST_PART",
	BuildingPartSetList = {
		{
			Name = "POND_SET1_NAME",
			BuildingPartList = { 
				"FISHPOND_PART1",
				"FISHPOND_PART2",
				"FISHPOND_PART3",
			}
        }
    },
    VillagerRequired = { Status = "SERF", Quantity = 18 }
})



-- Building Part: Post -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "POND_POST_PART",
	Name = "POND_POST_PART_NAME", 
	Description = "FISHPOND_DESC",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_POST"
	},
	IsVisibleWhenBuilt = false
})



-- Building part: Pond 1 -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "FISHPOND_PART1",
    Name = "FISHPOND_PART1_NAME",
    BuildingFunction = "FISHPOND1_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 9.5, {-0.5, 1.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
            },
            { 
                Polygon = polygon.createCircle( 7.0, {-0.5, 1.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
        }
    }, 
    ConstructionVisual = "PREFAB_POND1",
    ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_POND1"
        }, 
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 60 } },
		-- BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 1 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 10 } },
		RessourcesNeeded = {
            -- { Resource = "WOOD", Quantity = 5 }
		}
    },
    DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 28.0,
		Value = 0.5
	} }
})




-- Building part: Pond 2 -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "FISHPOND_PART2",
    Name = "FISHPOND_PART2_NAME",
    BuildingFunction = "FISHPOND2_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 7.5, {2.0, -2.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
            },
            { 
                Polygon = polygon.createCircle( 8.5, {-5.0, 4.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
            },
            { 
                Polygon = polygon.createCircle( 8.5, {-11.0, -1.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
            },

            { 
                Polygon = polygon.createCircle( 4.5, {2.5, -1.5}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
            { 
                Polygon = polygon.createCircle( 2.5, {-2.0, -2.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
            { 
                Polygon = polygon.createCircle( 2.5, {-0.5, 3.5}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
            { 
                Polygon = polygon.createCircle( 5.5, {-5.0, 4.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
            { 
                Polygon = polygon.createCircle( 5.2, {-11.0, -1.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
        },
    }, 
    ConstructionVisual = "PREFAB_POND2",
    ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_POND2"
        }, 
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 100 } },
		-- BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 1 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 14 } },
		RessourcesNeeded = {
            -- { Resource = "WOOD", Quantity = 5 }
		}
    },
    DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 35.0,
		Value = 0.5
	} }
})



-- Building part: Pond 3 -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "FISHPOND_PART3",
    Name = "FISHPOND_PART3_NAME",
    BuildingFunction = "FISHPOND2_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 13.5, {-0.5, 1.0}, 16 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
            },
            { 
                Polygon = polygon.createCircle( 8.5, {-0.5, 1.0}, 12 ), -- first number moves left and right, second moves up and down (with X forward)
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
            },
        }
    }, 
    ConstructionVisual = "PREFAB_POND3",
    ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_POND3"
        }, 
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 100 } },
		-- BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 1 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 14 } },
		RessourcesNeeded = {
            -- { Resource = "WOOD", Quantity = 5 }
		}
    },
    DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 35.0,
		Value = 0.5
	} }
})



-- Building Function: Fish Pond (1 worker) -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "FISHPOND1_FUNCTION",
    Name = "FISHPOND1_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "FISHERMAN", 
        Behavior = "WORK_BEHAVIOR"
    },
    ResourceProduced = {{ Resource = "FISH", Quantity = 1 }}
})


-- Building Function: Fish Pond (2 workers) -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "FISHPOND2_FUNCTION",
    Name = "FISHPOND2_FUNCTION_NAME",
    WorkerCapacity = 2,
    RelatedJob = { 
        Job = "FISHERMAN", 
        Behavior = "WORK_BEHAVIOR"
    },
    ResourceProduced = {{ Resource = "FISH", Quantity = 1 }}
})


